@@ -1,5 +1,10 @@
 //! Provides information about the network's clock which is made up of ticks, slots, etc...
 
+use {
+    crate::{clone_zeroed, copy_field},
+    std::mem::MaybeUninit,
+};
+
 // The default tick rate that the cluster attempts to achieve.  Note that the actual tick
 // rate at any given time should be expected to drift
 pub const DEFAULT_TICKS_PER_SECOND: u64 = 160;
@@ -105,7 +110,7 @@ pub type UnixTimestamp = i64;
 ///  as the network progresses).
 ///
 #[repr(C)]
-#[derive(Serialize, Clone, Deserialize, Debug, Default, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Default, PartialEq)]
 pub struct Clock {
     /// the current network/bank Slot
     pub slot: Slot,
@@ -121,3 +126,36 @@ pub struct Clock {
     /// timestamp_correction and timestamp_bounding features
     pub unix_timestamp: UnixTimestamp,
 }
+
+impl Clone for Clock {
+    fn clone(&self) -> Self {
+        clone_zeroed(|cloned: &mut MaybeUninit<Self>| {
+            let ptr = cloned.as_mut_ptr();
+            unsafe {
+                copy_field!(ptr, self, slot);
+                copy_field!(ptr, self, epoch_start_timestamp);
+                copy_field!(ptr, self, epoch);
+                copy_field!(ptr, self, leader_schedule_epoch);
+                copy_field!(ptr, self, unix_timestamp);
+            }
+        })
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_clone() {
+        let clock = Clock {
+            slot: 1,
+            epoch_start_timestamp: 2,
+            epoch: 3,
+            leader_schedule_epoch: 4,
+            unix_timestamp: 5,
+        };
+        let cloned_clock = clock.clone();
+        assert_eq!(cloned_clock, clock);
+    }
+}
